<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\exceptions;

/** A supplied TOTP or recovery code did not verify. */
class InvalidTwoFactorCodeException extends TwoFactorException
{
}
