<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\interfaces;


use apexl\Io\modules\user\services\JwtFromRequestService;
use Exception;
use Psr\Http\Message\ServerRequestInterface;

interface JwtFromRequestServiceFactoryInterface
{
    /**
     * @throws Exception
     */
    public function make(ServerRequestInterface $request): JwtFromRequestService;
}