<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\collections;

use apexl\Io\modules\user\entities\userEntity;
use apexl\Io\collections\EntityCollection;
use Arrayy\Arrayy;

/**
 * @extends Arrayy<array-key, userEntity>
 */
class userCollection extends EntityCollection
{
    public function getType(): string
    {
        return userEntity::class;
    }
}
